@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2022 Google LLC
+# Copyright 2024 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -19,6 +19,7 @@ import warnings
 from google.api_core import gapic_v1, grpc_helpers_async, operations_v1
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
+from google.cloud.location import locations_pb2  # type: ignore
 from google.longrunning import operations_pb2  # type: ignore
 from google.protobuf import empty_pb2  # type: ignore
 import grpc  # type: ignore
@@ -118,7 +119,7 @@ class DocumentServiceGrpcAsyncIOTransport(DocumentServiceTransport):
 
         Args:
             host (Optional[str]):
-                 The hostname to connect to.
+                 The hostname to connect to (default: 'discoveryengine.googleapis.com').
             credentials (Optional[google.auth.credentials.Credentials]): The
                 authorization credentials to attach to requests. These
                 credentials identify the application to the service; if none
@@ -347,7 +348,7 @@ class DocumentServiceGrpcAsyncIOTransport(DocumentServiceTransport):
     def update_document(
         self,
     ) -> Callable[
-        [document_service.UpdateDocumentRequest], Awaitable[document.Document]
+        [document_service.UpdateDocumentRequest], Awaitable[gcd_document.Document]
     ]:
         r"""Return a callable for the update document method over gRPC.
 
@@ -368,7 +369,7 @@ class DocumentServiceGrpcAsyncIOTransport(DocumentServiceTransport):
             self._stubs["update_document"] = self.grpc_channel.unary_unary(
                 "/google.cloud.discoveryengine.v1beta.DocumentService/UpdateDocument",
                 request_serializer=document_service.UpdateDocumentRequest.serialize,
-                response_deserializer=document.Document.deserialize,
+                response_deserializer=gcd_document.Document.deserialize,
             )
         return self._stubs["update_document"]
 
